@@ -10,7 +10,9 @@
 #'
 #' @export
 amino_acids <- function() {
-  c("Ser", "Arg", "Leu", "Pro", "Thr", "Ala", "Val", "Gly", "Ile",
+  c(
+    "Ser", "Arg", "Leu", "Pro", "Thr", "Ala", "Val", "Gly", "Ile",
     "Phe", "Tyr", "Cys", "His", "Gln", "Asn", "Lys", "Asp", "Glu",
-    "Met", "Trp")
+    "Met", "Trp"
+  )
 }
